summaryrefslogtreecommitdiffhomepage
path: root/Private/KernelKit/DeviceManager.hpp
diff options
context:
space:
mode:
Diffstat (limited to 'Private/KernelKit/DeviceManager.hpp')
-rw-r--r--Private/KernelKit/DeviceManager.hpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/Private/KernelKit/DeviceManager.hpp b/Private/KernelKit/DeviceManager.hpp
index 4eada620..10d23604 100644
--- a/Private/KernelKit/DeviceManager.hpp
+++ b/Private/KernelKit/DeviceManager.hpp
@@ -14,7 +14,7 @@
#pragma once
/* HCore device interface manager. */
/* @file KernelKit/DeviceManager.hpp */
/* @brief Device abstraction and I/O buffer. */
@@ -24,7 +24,7 @@
// Last Rev
// Sat Feb 24 CET 2024
-namespace HCore {
+namespace NewOS {
template <typename T>
class DeviceInterface;
@@ -105,4 +105,4 @@ enum {
kDeviceTypeMedia,
kDeviceTypeCount,
};
-} // namespace HCore
+} // namespace NewOS
@@ -14,7 +14,7 @@
#pragma once
-/* HCore device interface manager. */
+/* NewOS device interface manager. */
/* @file KernelKit/DeviceManager.hpp */
/* @brief Device abstraction and I/O buffer. */